"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SearchSelect = SearchSelect;
exports.SearchSelectField = void 0;

var _react = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _reactHooksShareable = require("react-hooks-shareable");

var _BaseSelect = require("./BaseSelect");

var _withField = require("../utils/withField");

var _excluded = ["value", "options", "onChange", "placeholder"];

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var InputNative = _styledComponents.default.input.withConfig({
  displayName: "SearchSelect__InputNative",
  componentId: "sc-3wix2a-0"
})(["font-family:", ";font-size:", ";line-height:", ";display:unset;overflow:hidden;text-overflow:ellipsis;width:100%;height:inherit;color:", ";background-color:transparent;border-width:0;outline:none;&::placeholder{color:", ";}"], _ref => {
  var {
    theme
  } = _ref;
  return theme.font.family;
}, _ref2 => {
  var {
    theme
  } = _ref2;
  return theme.font.size.regular;
}, _ref3 => {
  var {
    theme
  } = _ref3;
  return theme.font.lineHeight.large;
}, _ref4 => {
  var {
    theme
  } = _ref4;
  return theme.color.text01();
}, _ref5 => {
  var {
    theme
  } = _ref5;
  return theme.color.text05();
});

var getLabel = (value, options) => {
  var _options$find$label, _options$find;

  return (_options$find$label = (_options$find = options.find(option => option.value === value)) === null || _options$find === void 0 ? void 0 : _options$find.label) !== null && _options$find$label !== void 0 ? _options$find$label : value;
};

var getLabelComponent = (label, filter) => {
  var offset = label.toLocaleLowerCase().indexOf(filter.toLocaleLowerCase());

  if (offset === -1) {
    return label;
  }

  return /*#__PURE__*/_react.default.createElement("span", null, label.substring(0, offset), /*#__PURE__*/_react.default.createElement("strong", null, label.substring(offset, offset + filter.length)), label.substring(offset + filter.length));
};

function SearchSelect(_ref6) {
  var {
    value: currentValue,
    options,
    onChange,
    placeholder
  } = _ref6,
      props = _objectWithoutProperties(_ref6, _excluded);

  var [filter, setFilter] = (0, _react.useState)(currentValue);
  var [isTyping, startTyping, stopTyping] = (0, _reactHooksShareable.useBoolean)(false);
  var inputRef = (0, _react.useRef)(null);
  var filterLabel = (0, _react.useCallback)(text => text.toLocaleLowerCase().includes(filter.toLocaleLowerCase()), [filter]);
  var textOptions = (0, _react.useMemo)(() => {
    return options.filter(_ref7 => {
      var {
        label
      } = _ref7;
      return !isTyping || filterLabel(label);
    }).map(_ref8 => {
      var {
        value,
        disabled,
        label
      } = _ref8;
      return {
        value,
        disabled,
        component: getLabelComponent(label, filter)
      };
    });
  }, [options, isTyping, filterLabel, filter]);
  var onSelectChange = (0, _react.useCallback)(nextValue => {
    var _getLabel;

    setFilter((_getLabel = getLabel(nextValue, options)) !== null && _getLabel !== void 0 ? _getLabel : nextValue);
    onChange === null || onChange === void 0 ? void 0 : onChange(nextValue);
    stopTyping();
  }, [onChange, options, stopTyping]);
  var onFilterChange = (0, _react.useCallback)(e => {
    setFilter(e.target.value);
    startTyping();
  }, [startTyping]);
  var selectInputText = (0, _react.useCallback)(() => {
    var _inputRef$current;

    return (_inputRef$current = inputRef.current) === null || _inputRef$current === void 0 ? void 0 : _inputRef$current.select();
  }, []);
  var resetInputText = (0, _react.useCallback)(() => setFilter(getLabel(currentValue, options)), [currentValue, options]);
  (0, _react.useEffect)(() => setFilter(getLabel(currentValue, options)), [currentValue, options]);

  var input = /*#__PURE__*/_react.default.createElement(InputNative, {
    ref: inputRef,
    value: filter,
    onChange: onFilterChange,
    onFocus: selectInputText,
    onBlur: resetInputText,
    placeholder: placeholder
  });

  return /*#__PURE__*/_react.default.createElement(_BaseSelect.BaseSelect, _extends({
    value: currentValue,
    options: textOptions,
    component: input
  }, props, {
    onChange: onSelectChange
  }));
}

var SearchSelectField = props => (0, _withField.withField)(SearchSelect)(props);

exports.SearchSelectField = SearchSelectField;