"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.findPrevIndex = exports.findNextIndex = exports.scrollIntoView = exports.getWidth = void 0;

var _math = require("../utils/math");

/**
 * TODO: Fix width according to UX
 */
var getWidth = width => {
  switch (width) {
    case 'small':
      return '160px';

    case 'medium':
      return '220px';

    case 'large':
      return '300px';

    case 'full':
      return '100%';

    default:
      return '100%';
  }
};
/**
 * A scrollIntoView with fallback for Edge. For browsers that support it
 * this is identical to:
 *
 * `(element) => element.scrollIntoView({ block: 'nearest' })
 *
 * For other browser this is implemented with `element.scrollIntoView(true)`
 * or `element.scrollIntoView(false)` depending on the vertical offset. It
 * doesn't polyfill the full functionality of `scrollIntoView`.
 */


exports.getWidth = getWidth;

var scrollIntoView = element => {
  if ('scrollBehavior' in window.document.documentElement.style) {
    element.scrollIntoView({
      block: 'nearest'
    });
    return;
  }

  var parent = element.parentElement;
  var {
    height,
    top
  } = element.getBoundingClientRect();
  var {
    top: parentTop
  } = parent.getBoundingClientRect();
  var offset = top - parentTop;

  if (offset < 0) {
    element.scrollIntoView(true);
  } else if (offset + height > parent.clientHeight) {
    element.scrollIntoView(false);
  }
};

exports.scrollIntoView = scrollIntoView;

var findNextIndex = (index, options) => {
  var start = index === null ? 0 : index + 1;

  for (var i = start; i < start + options.length; i++) {
    var nextIndex = (0, _math.remainder)(i, options.length);

    if (options[nextIndex].disabled !== true) {
      return nextIndex;
    }
  }

  return index;
};

exports.findNextIndex = findNextIndex;

var findPrevIndex = (index, options) => {
  var start = index === null ? options.length - 1 : index - 1;

  for (var i = start; i > start - options.length; i--) {
    var nextIndex = (0, _math.remainder)(i, options.length);

    if (options[nextIndex].disabled !== true) {
      return nextIndex;
    }
  }

  return index;
};

exports.findPrevIndex = findPrevIndex;