"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SelectList = void 0;

var _react = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireWildcard(require("styled-components"));

var _designparams = require("../designparams");

var _Typography = require("../Typography");

var _excluded = ["value", "options", "onSelect", "maxHeight"];

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var LIST_ITEM_HEIGHT = 32;

var SelectListItem = _styledComponents.default.li.withConfig({
  displayName: "SelectList__SelectListItem",
  componentId: "sc-romwgd-0"
})(["height:", "px;padding:0 ", ";display:flex;flex-direction:column;align-items:left;justify-content:center;cursor:pointer;", ""], LIST_ITEM_HEIGHT, _designparams.spacing.medium, _ref => {
  var {
    disabled,
    selected
  } = _ref;

  if (disabled) {
    return (0, _styledComponents.css)(["color:", ";pointer-events:none;"], _ref2 => {
      var {
        theme
      } = _ref2;
      return theme.color.text04();
    });
  }

  if (selected) {
    return (0, _styledComponents.css)(["color:", ";background-color:", ";pointer-events:none;"], _ref3 => {
      var {
        theme
      } = _ref3;
      return theme.color.text00();
    }, _ref4 => {
      var {
        theme
      } = _ref4;
      return theme.color.elementPrimary();
    });
  }

  return (0, _styledComponents.css)(["&:hover{background-color:", ";}"], _ref5 => {
    var {
      theme
    } = _ref5;
    return theme.color.background02();
  });
});

var SelectListNative = _styledComponents.default.ul.withConfig({
  displayName: "SelectList__SelectListNative",
  componentId: "sc-romwgd-1"
})(["padding:0;outline:none;list-style:none;user-select:none;background-color:", ";color:", ";min-width:100%;border-radius:", ";display:block;max-height:", ";overflow:hidden;overflow-y:auto;"], _ref6 => {
  var {
    theme
  } = _ref6;
  return theme.color.background00();
}, _ref7 => {
  var {
    theme
  } = _ref7;
  return theme.color.text01();
}, _designparams.shape.radius.small, props => props.maxHeight);

/**
 * SelectList
 *
 * Is a scrollable list that a user may select one value from,
 * the selected value is highlighted.
 *
 * It differs from the normal Select component in the sense
 * that there is no button to open/close the list of options,
 * in SelectList the options is always visible to the user.
 *
 */
var SelectList = _ref8 => {
  var {
    value,
    options,
    onSelect,
    maxHeight = 320
  } = _ref8,
      props = _objectWithoutProperties(_ref8, _excluded);

  var listRef = (0, _react.useRef)(null);
  var onItemClick = (0, _react.useCallback)(e => {
    var clickValue = e.currentTarget.getAttribute('value');

    if (clickValue !== null) {
      onSelect(clickValue);
    }
  }, [onSelect]); // At first render _only_, scroll to the position of the selected item.

  (0, _react.useEffect)(() => {
    var index = options.findIndex(o => o.value === value);

    if (listRef.current !== null && index !== -1) {
      listRef.current.scrollTo(0, index * LIST_ITEM_HEIGHT);
    }
  }, []); // eslint-disable-line react-hooks/exhaustive-deps

  var searchForOption = (0, _react.useCallback)(e => {
    var keyPressed = e.key;
    var index = options.findIndex(o => o.value.charAt(0).toUpperCase() === keyPressed || o.value.charAt(0).toLowerCase() === keyPressed);

    if (listRef.current !== null && index !== -1) {
      listRef.current.scrollTo({
        top: index * LIST_ITEM_HEIGHT,
        behavior: 'smooth'
      });
    }
  }, [options, listRef]);
  return /*#__PURE__*/_react.default.createElement(SelectListNative, _extends({
    tabIndex: 0,
    onKeyUp: searchForOption,
    maxHeight: "".concat(maxHeight, "px"),
    ref: listRef
  }, props), options.map(option => /*#__PURE__*/_react.default.createElement(SelectListItem, {
    selected: value === option.value,
    key: option.value,
    value: option.value,
    disabled: option.disabled !== undefined,
    onClick: onItemClick,
    role: "menuitem"
  }, /*#__PURE__*/_react.default.createElement(_Typography.Typography, {
    variant: "default-text"
  }, option.label))));
};

exports.SelectList = SelectList;