import React from 'react';
declare type BaseElement = HTMLTextAreaElement;
declare type BaseProps = React.TextareaHTMLAttributes<BaseElement>;
export declare type TextAreaChangeHandler = React.ChangeEventHandler<BaseElement>;
export declare type TextAreaValueChangeHandler = (value: string) => void;
export interface TextAreaProps extends BaseProps {
    /**
     * Specifies the name of an input element.
     */
    readonly name?: BaseProps['name'];
    /**
     * `class` to be passed to the component.
     */
    readonly className?: string;
    /**
     * The value of the input element.
     */
    readonly value?: BaseProps['value'];
    /**
     * Native change handler that can be used by formik etc.
     */
    readonly onChange?: TextAreaChangeHandler;
    /**
     * Smooth typed value change handler.
     */
    readonly onValueChange?: TextAreaValueChangeHandler;
    /**
     * Executes an action when the Enter key is pressed.
     */
    readonly onPressEnter?: () => void;
    /**
     * Executes an action when the Esc key is pressed.
     */
    readonly onPressEscape?: () => void;
    /**
     * Adds an error message underneath the text area.
     */
    readonly error?: string | undefined;
    /**
     * Can be used to set React ref to the textarea element
     */
    readonly textareaRef?: React.RefObject<BaseElement>;
}
export declare const TextArea: React.FC<TextAreaProps>;
export declare const TextAreaField: React.FunctionComponent<import("../utils").FieldProps & TextAreaProps>;
export {};
